@@ -1,15 +1,17 @@
-/***********************************************************************/
-/*                                                                     */
-/*                                OCaml                                */
-/*                                                                     */
-/*         Xavier Leroy and Damien Doligez, INRIA Rocquencourt         */
-/*                                                                     */
-/*  Copyright 1996 Institut National de Recherche en Informatique et   */
-/*  en Automatique.  All rights reserved.  This file is distributed    */
-/*  under the terms of the GNU Library General Public License, with    */
-/*  the special exception on linking described in file ../LICENSE.     */
-/*                                                                     */
-/***********************************************************************/
+/**************************************************************************/
+/*                                                                        */
+/*                                 OCaml                                  */
+/*                                                                        */
+/*          Xavier Leroy and Damien Doligez, INRIA Rocquencourt           */
+/*                                                                        */
+/*   Copyright 1996 Institut National de Recherche en Informatique et     */
+/*     en Automatique.                                                    */
+/*                                                                        */
+/*   All rights reserved.  This file is distributed under the terms of    */
+/*   the GNU Lesser General Public License version 2.1, with the          */
+/*   special exception on linking described in the file LICENSE.          */
+/*                                                                        */
+/**************************************************************************/
 
 #ifndef CAML_CONFIG_H
 #define CAML_CONFIG_H
@@ -23,7 +25,6 @@
 #undef ARCH_BIG_ENDIAN
 #undef ARCH_ALIGN_DOUBLE
 #undef ARCH_ALIGN_INT64
-#undef NONSTANDARD_DIV_MOD
 #define ASM_CFI_SUPPORTED
 #define OCAML_OS_TYPE "Unix"
 #define OCAML_STDLIB_DIR "/usr/lib/ocaml"
@@ -36,6 +37,7 @@
 #define HAS_SOCKLEN_T
 #define HAS_INET_ATON
 #define HAS_IPV6
+#define HAS_STDINT_H
 #define HAS_UNISTD
 #define HAS_OFF_T
 #define HAS_DIRENT
@@ -78,29 +80,37 @@
 #define HAS_NICE
 #define HAS_SIGWAIT
 #define HAS_LIBBFD
+#define HAS_HUGE_PAGES
+#define HUGE_PAGE_SIZE (4 * 1024 * 1024)
 
 #ifndef CAML_NAME_SPACE
 #include "compatibility.h"
 #endif
 
-/* Types for 32-bit integers, 64-bit integers,
+#ifdef HAS_STDINT_H
+#include <stdint.h>
+#endif
+
+/* Types for 32-bit integers, 64-bit integers, and
    native integers (as wide as a pointer type) */
 
+#ifndef ARCH_INT32_TYPE
 #if SIZEOF_INT == 4
-typedef int int32;
-typedef unsigned int uint32;
+#define ARCH_INT32_TYPE int
+#define ARCH_UINT32_TYPE unsigned int
 #define ARCH_INT32_PRINTF_FORMAT ""
 #elif SIZEOF_LONG == 4
-typedef long int32;
-typedef unsigned long uint32;
+#define ARCH_INT32_TYPE long
+#define ARCH_UINT32_TYPE unsigned long
 #define ARCH_INT32_PRINTF_FORMAT "l"
 #elif SIZEOF_SHORT == 4
-typedef short int32;
-typedef unsigned short uint32;
+#define ARCH_INT32_TYPE short
+#define ARCH_UINT32_TYPE unsigned short
 #define ARCH_INT32_PRINTF_FORMAT ""
 #else
 #error "No 32-bit integer type available"
 #endif
+#endif
 
 #ifndef ARCH_INT64_TYPE
 #if SIZEOF_LONGLONG == 8
@@ -116,8 +126,19 @@ typedef unsigned short uint32;
 #endif
 #endif
 
-typedef ARCH_INT64_TYPE int64;
-typedef ARCH_UINT64_TYPE uint64;
+#ifndef HAS_STDINT_H
+/* Not a C99 compiler, typically MSVC.  Define the C99 types we use. */
+typedef ARCH_INT32_TYPE int32_t;
+typedef ARCH_UINT32_TYPE uint32_t;
+typedef ARCH_INT64_TYPE int64_t;
+typedef ARCH_UINT64_TYPE uint64_t;
+#if SIZEOF_SHORT == 2
+typedef short int16_t;
+typedef unsigned short uint16_t;
+#else
+#error "No 16-bit integer type available"
+#endif
+#endif
 
 #if SIZEOF_PTR == SIZEOF_LONG
 /* Standard models: ILP32 or I32LP64 */
@@ -130,9 +151,9 @@ typedef int intnat;
 typedef unsigned int uintnat;
 #define ARCH_INTNAT_PRINTF_FORMAT ""
 #elif SIZEOF_PTR == 8
-/* Win64 model: IL32LLP64 */
-typedef int64 intnat;
-typedef uint64 uintnat;
+/* Win64 model: IL32P64 */
+typedef int64_t intnat;
+typedef uint64_t uintnat;
 #define ARCH_INTNAT_PRINTF_FORMAT ARCH_INT64_PRINTF_FORMAT
 #else
 #error "No integer type available to represent pointers"
@@ -153,6 +174,7 @@ typedef uint64 uintnat;
 #define ARCH_FLOAT_ENDIANNESS 0x01234567
 #endif
 
+
 /* We use threaded code interpretation if the compiler provides labels
    as first-class values (GCC 2.x). */
 
@@ -162,14 +184,14 @@ typedef uint64 uintnat;
 #endif
 
 
-/* Do not change this definition. */
-#define Page_size (1 << Page_log)
-
 /* Memory model parameters */
 
 /* The size of a page for memory management (in bytes) is [1 << Page_log].
-   It must be a multiple of [sizeof (value)] and >= 8 and <= 20. */
+   [Page_size] must be a multiple of [sizeof (value)].
+   [Page_log] must be be >= 8 and <= 20.
+   Do not change the definition of [Page_size]. */
 #define Page_log 12             /* A page is 4 kilobytes. */
+#define Page_size (1 << Page_log)
 
 /* Initial size of stack (bytes). */
 #define Stack_size (4096 * sizeof(value))
@@ -184,10 +206,11 @@ typedef uint64 uintnat;
 /* Maximum size of a block allocated in the young generation (words). */
 /* Must be > 4 */
 #define Max_young_wosize 256
+#define Max_young_whsize (Whsize_wosize (Max_young_wosize))
 
 
 /* Minimum size of the minor zone (words).
-   This must be at least [Max_young_wosize + 1]. */
+   This must be at least [2 * Max_young_whsize]. */
 #define Minor_heap_min 4096
 
 /* Maximum size of the minor zone (words).
@@ -226,5 +249,12 @@ typedef uint64 uintnat;
  */
 #define Max_percent_free_def 500
 
+/* Default setting for the major GC slice smoothing window: 1
+   (i.e. no smoothing)
+*/
+#define Major_window_def 1
+
+/* Maximum size of the major GC slice smoothing window. */
+#define Max_major_window 50
 
 #endif /* CAML_CONFIG_H */
